@@ -4,10 +4,16 @@ NULL
 #'
 #'
 #'@description Provides a pipe-friendly framework to perform different types of
-#'  ANOVA tests, including: \itemize{ \item \strong{\href{https://www.datanovia.com/en/lessons/anova-in-r/}{Independent measures ANOVA}}:
-#'  between-Subjects designs, \item \strong{\href{https://www.datanovia.com/en/lessons/repeated-measures-anova-in-r/}{Repeated measures ANOVA}}:
-#'  within-Subjects designs \item \strong{\href{https://www.datanovia.com/en/lessons/mixed-anova-in-r/}{Mixed ANOVA}}: Mixed within within- and
-#'  between-Subjects designs, also known as split-plot ANOVA and \item \strong{\href{https://www.datanovia.com/en/lessons/ancova-in-r/}{ANCOVA: Analysis of Covariance}}. }
+#'  ANOVA tests, including: \itemize{ \item
+#'  \strong{\href{https://www.datanovia.com/en/lessons/anova-in-r/}{Independent
+#'  measures ANOVA}}: between-Subjects designs, \item
+#'  \strong{\href{https://www.datanovia.com/en/lessons/repeated-measures-anova-in-r/}{Repeated
+#'   measures ANOVA}}: within-Subjects designs \item
+#'  \strong{\href{https://www.datanovia.com/en/lessons/mixed-anova-in-r/}{Mixed
+#'  ANOVA}}: Mixed within within- and between-Subjects designs, also known as
+#'  split-plot ANOVA and \item
+#'  \strong{\href{https://www.datanovia.com/en/lessons/ancova-in-r/}{ANCOVA:
+#'  Analysis of Covariance}}. }
 #'
 #'  The function is an easy to use wrapper around \code{\link[car]{Anova}()} and
 #'  \code{\link[stats]{aov}()}. It makes ANOVA computation handy in R and It's
@@ -64,13 +70,15 @@ NULL
 #'@param x an object of class \code{anova_test}
 #'@param correction character. Used only in repeated measures ANOVA test to
 #'  specify which correction of the degrees of freedom should be reported for
-#'  the within-subject factors. Possible values are:
-#'  \itemize{
-#'  \item{"GG"}: applies Greenhouse-Geisser correction to all within-subjects factors even if the assumption of sphericity is met (i.e., Mauchly's test is not significant, p > 0.05).
-#'  \item{"HF"}: applies Hyunh-Feldt correction to all within-subjects factors even if the assumption of sphericity is met,
+#'  the within-subject factors. Possible values are: \itemize{ \item{"GG"}:
+#'  applies Greenhouse-Geisser correction to all within-subjects factors even if
+#'  the assumption of sphericity is met (i.e., Mauchly's test is not
+#'  significant, p > 0.05). \item{"HF"}: applies Hyunh-Feldt correction to all
+#'  within-subjects factors even if the assumption of sphericity is met,
 #'  \item{"none"}: returns the ANOVA table without any correction and
-#'  \item{"auto"}: apply automatically GG correction to only within-subjects factors violating the sphericity assumption (i.e., Mauchly's test p-value is significant, p <= 0.05).
-#'  }
+#'  \item{"auto"}: apply automatically GG correction to only within-subjects
+#'  factors violating the sphericity assumption (i.e., Mauchly's test p-value is
+#'  significant, p <= 0.05). }
 #'@seealso \code{\link{anova_summary}()}, \code{\link{factorial_design}()}
 #'@return return an object of class \code{anova_test} a data frame containing
 #'  the ANOVA table for independent measures ANOVA.
@@ -84,7 +92,19 @@ NULL
 #'  list holding the arguments used to fit the ANOVA model, including: data, dv,
 #'  within, between, type, model, etc.
 #'
-#'
+#'@details The setting in \code{anova_test()} is done in such a way that it
+#'  gives the same results as SPSS, one of the most used commercial software. By
+#'  default, R uses treatment contrasts, where each of the levels is compared to
+#'  the first level used as baseline. The default contrast can be checked using
+#'  \code{options('contrasts')}. In the function \code{anova_test()}, the
+#'  following setting is used
+#'  \code{options(contrasts=c('contr.sum','contr.poly'))}, which gives
+#'  orthogonal contrasts where you compare every level to the overall mean. This
+#'  setting gives the same output as the most commonly used commercial
+#'  softwares, like SPSS. If you want to obtain the same result with the
+#'  function \code{car::Anova()} as the one obtained with
+#'  \code{rstatix::anova_test()}, then don't forget to set
+#'  \code{options(contrasts=c('contr.sum','contr.poly'))}.
 #'@author Alboukadel Kassambara, \email{alboukadel.kassambara@@gmail.com}
 #' @examples
 #' # Load data
@@ -172,9 +192,12 @@ anova_test <- function(data, formula, dv, wid, between, within, covariate, type
       result = "anova"
     )
     if("anova" %in% colnames(results)){
+      # This happens for repeated measure anova
       results <- results %>%
         mutate(anova = map(.data$anova, .append_anova_class))
     }
+    results <- results %>% set_attrs(args = list(data = data))
+    class(results) <- c("grouped_anova_test", class(results), "rstatix_test")
   }
   else{
     results <- .anova_test(
@@ -260,9 +283,10 @@ get_anova_table_from_grouped_test <- function(x, correction = "auto"){
   }
   extract_table <- function(x, correction){
     get_anova_table_from_simple_test(x, correction = correction) %>%
-      remove_class(c("anova_test", "rstatix_test"))
+      remove_class(c("anova_test",  "rstatix_test"))
   }
   x %>%
+    keep_only_tbl_df_classes() %>%
     mutate(anova = map(.data$anova, extract_table, correction = correction)) %>%
     unnest(cols = "anova")
 }
@@ -448,7 +472,10 @@ fit_lm <- function(.args){
   .args <- remove_missing_values_in_data(.args)
   lm_data <- droplevels(.args$data)
   lm_formula <- .args$formula
-  stats::lm(lm_formula, lm_data)
+  opt <- options( "contrasts" = c( "contr.sum", "contr.poly" ) )
+  results <- stats::lm(lm_formula, lm_data)
+  options(opt)
+  results
 }
 
 # Compute the different types of ANOVA -----------------------------
@@ -456,10 +483,10 @@ fit_lm <- function(.args){
 car_anova <- function(.args, ...){
   if(has_model(.args)){
     .model <- get_anova_model(.args)
-    res.anova <- car::Anova(
+    res.anova <- suppressMessages(car::Anova(
       .model, type = .args$type,
       white.adjust = .args$white.adjust, ...
-    )
+    ))
     .args$model <- .model
   }
   else{
@@ -468,16 +495,16 @@ car_anova <- function(.args, ...){
       within = .args$within, covariate = .args$covariate
       )
     if(is_independent_anova(.args)){
-      res.anova <- Anova(
+      res.anova <- suppressMessages(Anova(
         design$model, type = .args$type,
         white.adjust = .args$white.adjust, ...
-      )
+      ))
     }
     else{
-      res.anova <- Anova(
+      res.anova <- suppressMessages(Anova(
         design$model, idata = design$idata,
         idesign = design$idesign, type = .args$type, ...
-      )
+      ))
     }
    .args$model <- design$model
   }
